package com.chelvc.framework.base.model;

import java.io.Serializable;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;

/**
 * 会话信息
 *
 * @author Woody
 * @date 2023/4/5
 */
@Getter
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class Session implements Serializable {
    /**
     * 主体标识
     */
    private Long id;

    /**
     * 会话类型
     */
    private Type type;

    /**
     * 请求地址
     */
    private String host;

    /**
     * 设备标识
     */
    private String device;

    /**
     * 租户编号
     */
    private Integer tenant;

    /**
     * 渠道来源
     */
    private String channel;

    /**
     * 是否是首次请求
     */
    private Boolean initial;

    /**
     * 应用平台
     */
    private Platform platform;

    /**
     * 客户终端
     */
    private Terminal terminal;

    /**
     * 客户端版本号
     */
    private String version;

    /**
     * 签名信息
     */
    private String signature;

    /**
     * 客户端序号
     */
    private Integer sequence;

    /**
     * 会话类型枚举
     */
    public enum Type {
        /**
         * 管理员
         */
        ADMIN,

        /**
         * 普通用户
         */
        NORMAL,

        /**
         * 客户端
         */
        CLIENT;
    }
}
